==> mod_fast_bbs-1.0.2.tgz: mod_fast_bbs-1.0.2/include/All.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: All.h 1984 2006-11-12 06:43:10Z svn $
 *****************************************************************************/

#ifndef ALL_H
#define ALL_H

#include "AtomicWrapper.h"
#include "Auxiliary.h"
#include "BBSCommentIterator.h"
#include "BBSCommentVariableCreator.h"
#include "BBSConfig.h"
#include "BBSConfigReader.h"
#include "BBSTemplate.h"
#include "BBSThread.h"
#include "BBSThreadIO.h"
#include "BBSThreadList.h"
#include "BBSThreadListReader.h"
#include "BBSThreadManager.h"
#include "BBSThreadReader.h"
#include "BBSCommentVariableCreator.h"
#include "BBSThreadWriter.h"
#include "BasicFileWriter.h"
#include "CleanPointer.h"
#include "ConfigReader.h"
#include "DirectoryCleaner.h"
#include "File.h"
#include "FileWriter.h"
#include "ImageFile.h"
#include "Locker.h"
#include "Logger.h"
#include "Macro.h"
#include "Message.h"
#include "MessageDigest5.h"
#include "MmapCommentIterator.h"
#include "MmapFileWriter.h"
#include "PostDataChecker.h"
#include "PostFlowController.h"
#include "RFC1867Parser.h"
#include "RFC1867ParserBuffer.h"
#include "ReadLocker.h"
#include "ReadWriteLocker.h"
#include "ShmCommentIterator.h"
#include "SourceInfo.h"
#include "SpamChecker.h"
#include "TemplateLexer.h"
#include "TemplateParser.h"
#include "TemplateVariable.h"
#include "TemplateVariableCreator.h"
#include "TemporaryFile.h"
#include "TemporaryPool.h"
#include "Uncopyable.h"
#include "WriteLocker.h"

#include "apr.h"
#include "apr_file_info.h"
#include "apr_file_io.h"
#include "apr_general.h"
#include "apr_global_mutex.h"
#include "apr_mmap.h"
#include "apr_pools.h"
#include "apr_shm.h"
#include "apr_strings.h"
#include "apr_tables.h"
#include "apr_thread_cond.h"
#include "apr_thread_mutex.h"
#include "apr_thread_proc.h"
#include "apr_time.h"

#include <algorithm>
#include <cstdarg>
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <functional>
#include <iomanip>
#include <iostream>
#include <memory>
#include <string>
#include <vector>

#include <limits.h>

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:

==> mod_fast_bbs-1.0.5.tgz: mod_fast_bbs-1.0.5/include/All.h <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: All.h 2328 2006-12-29 18:52:20Z svn $
 *****************************************************************************/

#ifndef ALL_H
#define ALL_H

#include "AtomicWrapper.h"
#include "Auxiliary.h"
#include "BBSCommentIterator.h"
#include "BBSCommentVariableCreator.h"
#include "BBSCommentVariableCreator.h"
#include "BBSConfig.h"
#include "BBSConfigReader.h"
#include "BBSTemplate.h"
#include "BBSThread.h"
#include "BBSThreadIO.h"
#include "BBSThreadList.h"
#include "BBSThreadListReader.h"
#include "BBSThreadManager.h"
#include "BBSThreadReader.h"
#include "BBSThreadWriter.h"
#include "BasicFileWriter.h"
#include "CleanPointer.h"
#include "ConfigReader.h"
#include "DirectoryCleaner.h"
#include "File.h"
#include "FileWriter.h"
#include "ImageFile.h"
#include "Locker.h"
#include "Logger.h"
#include "Macro.h"
#include "Message.h"
#include "MessageDigest5.h"
#include "MmapCommentIterator.h"
#include "MmapFileWriter.h"
#include "MultipartMessageParser.h"
#include "MultipartMessageParserBuffer.h"
#include "PostDataChecker.h"
#include "PostFlowController.h"
#include "RFC1867Parser.h"
#include "ReadLocker.h"
#include "ReadWriteLocker.h"
#include "ShmCommentIterator.h"
#include "SourceInfo.h"
#include "SpamChecker.h"
#include "TemplateLexer.h"
#include "TemplateParser.h"
#include "TemplateVariable.h"
#include "TemplateVariableCreator.h"
#include "TemporaryFile.h"
#include "TemporaryPool.h"
#include "Uncopyable.h"
#include "WriteLocker.h"

#include "apr.h"
#include "apr_file_info.h"
#include "apr_file_io.h"
#include "apr_general.h"
#include "apr_global_mutex.h"
#include "apr_mmap.h"
#include "apr_pools.h"
#include "apr_shm.h"
#include "apr_strings.h"
#include "apr_tables.h"
#include "apr_thread_cond.h"
#include "apr_thread_mutex.h"
#include "apr_thread_proc.h"
#include "apr_time.h"

#include <algorithm>
#include <cstdarg>
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <ctime>
#include <functional>
#include <iomanip>
#include <iostream>
#include <memory>
#include <string>
#include <vector>

#include <limits.h>

#endif

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
